@@ -1,6 +1,6 @@
 import scipy.signal
 import asyncio
-import argparse
+import textwrap
 import numpy as np
 
 import joule
@@ -70,7 +70,8 @@ ARGS_DESC = """
     exec_cmd = joule-median-filter
 
     [Arguments]
-    window = 11 # must be odd
+    # must be odd
+    window = 11
 
     [Inputs]
     input = /path/to/input
@@ -84,14 +85,12 @@ ARGS_DESC = """
 class MedianFilter(joule.FilterModule):
     """Compute the median of the input"""
 
-   # def __init__(self):
-   #     super(MedianFilter, self).__init__()
-
     def custom_args(self, parser):  # pragma: no cover
-        parser.add_argument("window", type=int,
-                            help="window length")
-        parser.description = ARGS_DESC
-        parser.formatter_class = argparse.RawDescriptionHelpFormatter
+        grp = parser.add_argument_group("module",
+                                        "module specific arguments")
+        grp.add_argument("--window", type=int, required=True,
+                         help="window length")
+        parser.description = textwrap.dedent(ARGS_DESC)
 
     async def run(self, parsed_args, inputs, outputs):
         N = parsed_args.window
