@@ -58,8 +58,6 @@ class Visualizer(FilterModule):  # pragma: no cover
             for pipe in inputs.values():
                 data = await pipe.read()
                 pipe.consume(len(data))
-                print("got %d rows from %s" % (len(data), pipe.stream.name), flush=True)
-                print("pipe.stream.elements: %d" % len(pipe.stream.elements))
                 if len(data) == 0:
                     continue
                 for i in range(len(pipe.stream.elements)):
@@ -80,8 +78,7 @@ class Visualizer(FilterModule):  # pragma: no cover
                         global_max = self.elements[i + offset]['max']
                         self.elements[i + offset]['max'] = max((data_max, global_max))
                 offset += len(pipe.stream.elements)
-            for e in self.elements:
-                print(e)
+
             await asyncio.sleep(1)
 
     def routes(self):
