@@ -19,7 +19,8 @@ def info(config):
 
 
 @click.command(name="initialize")
-def initialize():
+@click.option("--dsn", help="PostgreSQL DSN", required=True)
+def initialize(dsn):  # pragma: no cover
     click.echo("1. creating joule user ", nl=False)
     proc = subprocess.run("useradd -r -G dialout joule".split(" "), stderr=subprocess.PIPE)
     if proc.returncode == 0:
@@ -47,9 +48,18 @@ def initialize():
     _make_joule_directory("/etc/joule")
     # check if main.conf exists
     if not os.path.isfile("/etc/joule/main.conf"):
-        conf_file = pkg_resources.resource_filename(
+        conf_template = pkg_resources.resource_filename(
             "joule", "resources/templates/main.conf")
-        shutil.copy(conf_file, "/etc/joule")
+        with open(conf_template, 'r') as template:
+            with open("/etc/joule/main.conf", 'w') as conf:
+                line = template.readline()
+                while line:
+                    if "REPLACE_WITH_DSN" in line:
+                        conf.write("Database = %s\n" % dsn)
+                    else:
+                        conf.write(line)
+                    line = template.readline()
+
     # set ownership to joule user
     shutil.chown("/etc/joule/main.conf", user="joule", group="joule")
 
@@ -101,7 +111,7 @@ def initialize():
     click.echo("[" + click.style("OK", fg='green') + "]")
 
 
-def _make_joule_directory(path):
+def _make_joule_directory(path):  # pragma: no cover
     try:
         if os.path.isfile(path):
             click.echo("\n "+click.style("ERROR", fg='red') +
@@ -116,6 +126,6 @@ def _make_joule_directory(path):
         _run_as_root()
 
 
-def _run_as_root():
+def _run_as_root():  # pragma: no cover
     click.echo("[" + click.style("ERROR", fg="red") + "]\n run as [sudo joule initialize]")
     exit(1)
